@@ -52,6 +52,8 @@ PATTERNS['S'] = PATTERNS['second']
 
 
 class SmartLab:
+    save_dir: Path
+    version: str
     remote: str = 'origin'
 
     def new(
@@ -87,34 +89,34 @@ class SmartLab:
                 save_dir=save_dir,
                 version=version,
             )
-            save_dir = save_dir.joinpath(
-                version.format(
-                    number=number,
-                    n=number,
-                    hash=token_hex(16),
-                    h8=token_hex(4),
-                    h6=token_hex(3),
-                    h4=token_hex(2),
-                    uuid=uuid.uuid4(),
-                    adjective=adjective,
-                    adj=adjective,
-                    noun=noun,
-                    year=year,
-                    Y=year,
-                    month=month,
-                    m=month,
-                    day=day,
-                    d=day,
-                    hour=hour,
-                    H=hour,
-                    minute=minute,
-                    M=minute,
-                    second=second,
-                    S=second,
-                    microsecond=date.microsecond,
-                )
+            self.version = version.format(
+                number=number,
+                n=number,
+                hash=token_hex(16),
+                h8=token_hex(4),
+                h6=token_hex(3),
+                h4=token_hex(2),
+                uuid=uuid.uuid4(),
+                adjective=adjective,
+                adj=adjective,
+                noun=noun,
+                year=year,
+                Y=year,
+                month=month,
+                m=month,
+                day=day,
+                d=day,
+                hour=hour,
+                H=hour,
+                minute=minute,
+                M=minute,
+                second=second,
+                S=second,
+                microsecond=date.microsecond,
             )
+            save_dir = save_dir.joinpath(self.version)
 
+        self.save_dir = save_dir
         save_dir.mkdir(parents=True, exist_ok=True)
         return save_dir
 
