@@ -11,6 +11,7 @@ class SmartRegister:
     def __init__(self) -> None:
         self._aliases: Dict[str, str] = dict()
         self._origins: Dict[str, str] = dict()
+        self._classes: Dict[str, Callable] = dict()
 
     @property
     def aliases(self) -> Dict[str, str]:
@@ -20,6 +21,23 @@ class SmartRegister:
     def origins(self) -> Dict[str, str]:
         return self._origins.copy()
 
+    def callable(
+        self,
+        alias: str,
+    ) -> Callable:
+        """Get callable of given alias.
+
+        Args:
+            alias: Alias for callable.
+
+        Returns:
+            Callable object.
+
+        """
+        origin = self._origins[alias]
+        name, option = typeutil.parse_class_name(origin)
+        return typeutil.import_callable(name, f'[{SmartRegister.__name__}]')
+
     def reset(self) -> None:
         """Removes all registered classes and aliases."""
         self._aliases.clear()
