@@ -1,4 +1,5 @@
 import copy
+import hashlib
 import inspect
 import os
 import re
@@ -214,30 +215,56 @@ class Smart(Generic[T]):
     def __hash__(self) -> int:
         return hash(strutil.join_keys(self._trace, repr(self)))
 
+    def hash(self) -> str:
+        """Returns hash of params."""
+        items = sorted(self.items(flatten=True, pattern='^[^.]+(?:[.][^.]+)*$'))
+        representation = ','.join(f'{k}={repr(v)}' for k, v in items)
+        return hashlib.sha256(representation.encode()).hexdigest()
+
     def type(
         self,
         return_type: bool = True,
     ) -> Union[Type[T], Callable[..., T]]:
+        """Returns annotation type or callable object.
+
+        Args:
+            return_type: Whether to return type from callable type annotation.
+
+        Returns:
+            Type or callable object.
+
+        """
         if return_type:
             return typeutil.get_return_type(self._callable)
         return self._callable
 
     def dict(
         self,
-        squash: bool = False,
+        flatten: bool = False,
         minimal: bool = False,
         unpack: bool = False,
     ) -> Dict[str, Any]:
+        """Returns params.
+
+        Args:
+            flatten: Whether to flatten keys.
+            minimal: Whether to remove unnecessary parents.
+            unpack: Whether to update dictionary from dictionaries with empty key.
+
+        Returns:
+            Params dictionary.
+
+        """
         if unpack:
             dictionary = dictutil.unpack_empty_keys(self._params)
         else:
             dictionary = self._params
 
-        if squash or minimal:
+        if flatten or minimal:
             dictionary = dict(Smart(**dictionary).items(flatten=True))
             if minimal:
                 dictionary = dictutil.flatten_unique_keys(dictionary)
-                if not squash:
+                if not flatten:
                     return dictutil.normalize(dictionary)
 
             return dictionary
@@ -263,7 +290,7 @@ class Smart(Generic[T]):
         if pattern is None:
             yield from keys
         else:
-            yield from (key for key in keys if re.fullmatch(pattern, key))
+            yield from (key for key in keys if re.search(pattern, key))
 
     def values(
         self,
@@ -494,6 +521,7 @@ class Smart(Generic[T]):
         source: Union['Smart', Mapping[str, Any], Sequence[str], str, Path],
         source_key: Optional[str] = None,
         target_key: Optional[str] = None,
+        mode: Optional[str] = None,
         override: bool = True,
         required: bool = True,
     ) -> 'Smart[T]':
@@ -503,6 +531,7 @@ class Smart(Generic[T]):
             source: Smart object, dictionary, list or path of new items to update.
             source_key: Key of source object to update.
             target_key: Key of smart object to be updated.
+            mode: Mode of params file if source is path.
             override: Whether to override existing items.
             required: Whether the source_key is required to exist.
 
@@ -517,7 +546,17 @@ class Smart(Generic[T]):
         if isinstance(source, Smart):
             smart = source
         elif isinstance(source, (str, Path)):
-            smart = Smart(**load_data(Path(source)))
+            path = Path(source)
+            if not path.exists() and not required:
+                if mode is None:
+                    return self
+                smart = Smart()
+            else:
+                smart = Smart(**load_data(path))
+
+            if mode is not None:
+                for mode_path, mode_required in strutil.parse_mode(path, mode):
+                    smart.update_from(source=mode_path, required=mode_required)
         elif isinstance(source, Mapping):
             smart = Smart(**source)
         elif isinstance(source, Sequence):
@@ -549,12 +588,14 @@ class Smart(Generic[T]):
         cls,
         source: Union['Smart', Mapping[str, Any], Sequence[str], str, Path],
         key: Optional[str] = None,
+        mode: Optional[str] = None,
     ) -> 'Smart':
         """Loads object from the given source.
 
         Args:
             source: Smart object, dictionary, list or path of object to load.
             key: Key of source dictionary.
+            mode: Mode of params file if source is path.
 
         Returns:
             Smart object with loaded given source.
@@ -563,7 +604,7 @@ class Smart(Generic[T]):
             TypeError if given source is not supported.
 
         """
-        return cls().update_from(source=source, source_key=key)
+        return cls().update_from(source=source, source_key=key, mode=mode)
 
     def copy(
         self,
@@ -686,11 +727,11 @@ class Smart(Generic[T]):
         Smart.debug = Smart.debug or args.debug
 
         if args.path:
-            if args.path.exists():
-                self.update_from(args.path)
-            if args.mode:
-                for path_mode in strutil.get_mode_paths(args.path, args.mode):
-                    self.update_from(path_mode)
+            self.update_from(
+                source=args.path,
+                mode=args.mode,
+                required=False,
+            )
 
         self.update_from(args.params)
 
