@@ -9,6 +9,7 @@ OBJECT_SEPARATOR = ':'
 PARAM_SEPARATOR = '='
 MODE_SEPARATOR = ','
 PATH_SEPARATOR = '/'
+OPTIONAL_SUFFIX = '?'
 
 
 def join_keys(*args: Optional[str]) -> str:
@@ -44,14 +45,21 @@ def to_bool(value: str) -> bool:
     raise ValueError(f"String value '{value}' is not like to boolean.")
 
 
-def get_mode_paths(
+def parse_mode(
     path: Path,
     mode: str,
-) -> List[Path]:
-    mode_paths = []
+) -> List[Tuple[Path, bool]]:
+    modes = []
     for mode in mode.split(MODE_SEPARATOR):
         *sub_dir, mode = mode.split(PATH_SEPARATOR)
-        suffix = f'.{mode}{path.suffix}'
-        mode_paths.append(path.parent.joinpath(*sub_dir, path.stem).with_suffix(suffix))
 
-    return mode_paths
+        if mode.endswith(OPTIONAL_SUFFIX):
+            required = False
+            mode = mode[:-1]
+        else:
+            required = True
+
+        suffix = f'.{mode}{path.suffix}'
+        modes.append((path.parent.joinpath(*sub_dir, path.stem).with_suffix(suffix), required))
+
+    return modes
