@@ -1,3 +1,4 @@
+import tempfile
 from copy import deepcopy
 from pathlib import Path
 from typing import Any, Dict, List, Tuple, Union
@@ -59,6 +60,15 @@ class TestSmart(UnitCase):
 
         self.assertIsInstance(smart_hash, int)
 
+    def test__hash(self) -> None:
+        smart1: Smart = Smart(Class, a={'10': 1, '3': 9}, c=[1, 2, 3], b={'2': 3})
+        smart2: Smart = Smart(Class, b={'2': 3, '': {'2': 7}}, a={'3': 9, '10': 1}, c=[1, 2, 3])
+
+        smart_hash1 = smart1.hash()
+        smart_hash2 = smart2.hash()
+
+        self.assertEqual(smart_hash1, smart_hash2)
+
 
 class TestSmartCallCase(UnitCase):
     def setUp(self) -> None:
@@ -110,7 +120,7 @@ class TestSmartDictCase(UnitCase):
         expected = {'a.b': 1, 'a.c': 2, 'b': 3, 'd': {1: 'x'}}
         smart: Smart = Smart(a={'b': 1, 'c': 2}, b=3, d={1: 'x'})
 
-        actual = smart.dict(squash=True)
+        actual = smart.dict(flatten=True)
 
         self.assertEqual(expected, actual)
 
@@ -126,7 +136,7 @@ class TestSmartDictCase(UnitCase):
         expected = {'a.b': 1, 'c': 2, 'b': 3, 'd': {1: 'x'}}
         smart: Smart = Smart(a={'b': 1, 'c': 2}, b=3, d={1: 'x'})
 
-        actual = smart.dict(squash=True, minimal=True)
+        actual = smart.dict(flatten=True, minimal=True)
 
         self.assertEqual(expected, actual)
 
@@ -247,6 +257,56 @@ class TestSmartDictCase(UnitCase):
                 self.assertEqual('argument31', smart.dict()['arg3']['arg31'])
                 self.assertEqual('a32', smart.dict()['arg3']['arg32'])
 
+    def test_update__path(self) -> None:
+        with tempfile.TemporaryDirectory() as dirname:
+            directory = Path(dirname)
+            directory.joinpath('params.yaml').write_text('a: 1\nb: 2')
+            directory.joinpath('params.dev.yaml').write_text('c: 3\nb: 4')
+            expected = dict(a=1, b=4, c=3)
+            smart: Smart = Smart()
+
+            smart.update_from(source=directory.joinpath('params.yaml'), mode='dev')
+
+            self.assertEqual(expected, smart._params)
+
+    def test_update__path__not_required_path(self) -> None:
+        with tempfile.TemporaryDirectory() as dirname:
+            directory = Path(dirname)
+            directory.joinpath('params.dev.yaml').write_text('c: 3\nb: 4')
+            expected = dict(b=4, c=3)
+            smart: Smart = Smart()
+
+            smart.update_from(source=directory.joinpath('params.yaml'), mode='dev', required=False)
+
+            self.assertEqual(expected, smart._params)
+
+    def test_update__path__not_required_dev(self) -> None:
+        with tempfile.TemporaryDirectory() as dirname:
+            directory = Path(dirname)
+            directory.joinpath('params.yaml').write_text('a: 1\nb: 2')
+            expected = dict(a=1, b=2)
+            smart: Smart = Smart()
+
+            smart.update_from(source=directory.joinpath('params.yaml'), mode='dev?')
+
+            self.assertEqual(expected, smart._params)
+
+    def test_update__path__required_path__error(self) -> None:
+        with tempfile.TemporaryDirectory() as dirname:
+            directory = Path(dirname)
+            path = directory.joinpath('params.yaml')
+            directory.joinpath('params.dev.yaml').write_text('c: 3\nb: 4')
+
+            self.assertRaises(FileNotFoundError, self.smart.update_from, source=path, mode='dev')
+
+    def test_update__path__required_dev__error(self) -> None:
+        with tempfile.TemporaryDirectory() as dirname:
+            directory = Path(dirname)
+            path = directory.joinpath('params.yaml')
+            path.write_text('a: 1\nb: 2')
+
+            self.assertRaises(FileNotFoundError, self.smart.update_from, source=path, mode='dev')
+
     @patch('smartparams.smart.load_data')
     def test_update__not_override(self, load_data: Mock) -> None:
         dictionary = {'arg1': {'nested1': 'aa1'}, 'arg3': {'arg31': 'aa31'}, 'arg4': {'a4': 'aa4'}}
